@@ -302,10 +302,11 @@ namespace msXpSlibmass
 					// order, we do not make an append() call, but a combine call.
 					// Further, this has the advantage that if two same keys appear
 					// in the initializing text, then they are combined and not simply
-					// appended.
+					// appended. Note that combining a O-val DataPoint is not performed.
 
-					combine(dataPoint);
-					++dataPointCount;
+					int res = combine(dataPoint);
+					if(res != -1)
+						++dataPointCount;
 				}
 				else
 					qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
@@ -1996,23 +1997,23 @@ namespace msXpSlibmass
 		For each DataPoint instance of \c this Trace, append a textual
 		representation of the (key,value) pair to a heap-allocated string.
 
-		\return a heap-allocated string containing a textual representation of \c this
+		\return a string containing a textual representation of \c this
 		Trace. The object must be delete when no more in use.
 
 */
-	QString *
+	QString
 		Trace::asText(int startIndex, int endIndex)
 		{
-			QList<double> keyLista = keyList();
-			QList<double> valLista = valList();
+			QList<double> keys = keyList();
+			QList<double> values = valList();
 
-			int dataPointCount = keyLista.size();
+			int dataPointCount = keys.size();
 
 			// Even if the spectrum is empty, we should return an empty string.
-			QString *p_text = new QString();
+			QString text;
 
 			if(dataPointCount == 0)
-				return p_text;
+				return text;
 
 			int indexStart = (startIndex <= 0 ? 0 : startIndex);
 			if(indexStart >= dataPointCount - 1)
@@ -2024,12 +2025,12 @@ namespace msXpSlibmass
 
 			for(int iter = indexStart; iter <= indexEnd; ++iter)
 			{
-				p_text->append(QString("%1 %2\n")
-						.arg(keyLista.at(iter), 0, 'f', 10)
-						.arg(valLista.at(iter), 0, 'f', 10));
+				text.append(QString("%1 %2\n")
+						.arg(keys.at(iter), 0, 'f', 10)
+						.arg(values.at(iter), 0, 'f', 10));
 			}
 
-			return p_text;
+			return text;
 		}
 
 
@@ -2045,12 +2046,10 @@ namespace msXpSlibmass
 			if(!file.open(QIODevice::WriteOnly))
 				return false;
 
-			QString *p_xyString = asText(-1, -1);
+			QString text = asText(-1, -1);
 
 			QTextStream out(&file);
-			out << *p_xyString;
-
-			delete p_xyString;
+			out << text;
 
 			file.close();
 
