@@ -1,34 +1,35 @@
-/*  BEGIN software license
+/* BEGIN software license
  *
- *  msXpertSuite - mass spectrometry software suite
- *  -----------------------------------------------
- *  Copyright(C) 2009, 2017 Filippo Rusconi
+ * msXpertSuite - mass spectrometry software suite
+ * -----------------------------------------------
+ * Copyright(C) 2009,...,2018 Filippo Rusconi
  *
- *  http://www.msxpertsuite.org
+ * http://www.msxpertsuite.org
  *
- *  This file is part of the msXpertSuite project.
+ * This file is part of the msXpertSuite project.
  *
- *  The msXpertSuite project is the successor of the massXpert project. This
- *  project now includes various independent modules:
- *  
- *  - massXpert, model polymer chemistries and simulate mass spectrometric data;
- *  - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
+ * The msXpertSuite project is the successor of the massXpert project. This
+ * project now includes various independent modules:
  *
- *  This program is free software: you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation, either version 3 of the License, or
- *  (at your option) any later version.
+ * - massXpert, model polymer chemistries and simulate mass spectrometric data;
+ * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
  * END software license
-*/
+ */
+
 
 
 
@@ -49,7 +50,7 @@ namespace msXpSmassXpert
 			/* no polymer **/
 			/* no PolChemDef **/
 			const QString &settingsFilePath)
-		: 
+		:
 			AbstractSeqEdWndDependentDlg(editorWnd,
 					0, /*polymer **/
 					0, /*polChemDef **/
@@ -70,7 +71,7 @@ namespace msXpSmassXpert
 	}
 
 
-	bool 
+	bool
 		MonomerModificationDlg::initialize()
 		{
 			m_ui.setupUi(this);
@@ -123,7 +124,7 @@ namespace msXpSmassXpert
 		}
 
 
-	void 
+	void
 		MonomerModificationDlg::readSettings()
 		{
 			QSettings settings(m_configSettingsFilePath, QSettings::IniFormat);
@@ -135,7 +136,7 @@ namespace msXpSmassXpert
 		}
 
 
-	void 
+	void
 		MonomerModificationDlg::writeSettings()
 		{
 
@@ -611,7 +612,7 @@ namespace msXpSmassXpert
 				QMessageBox::warning(this,
 						tr("massXpert - Modify monomers"),
 						tr("No target is selected."),
-						QMessageBox::Ok);;
+						QMessageBox::Ok);
 				return 0;
 			}
 
