@@ -90,7 +90,7 @@ namespace msXpSmineXpert
 			desc, massSpecDataSet, fileName, isMultiGraph}
 	{
 		AbstractPlotWidget::registerQtKeyCode(Qt::Key_R,
-				"Press T while right mouse click-drag to integrate to a XIC chromatogram");
+				"Press R while right mouse click-drag to integrate to a XIC chromatogram");
 		AbstractPlotWidget::registerQtKeyCode(Qt::Key_S,
 				"Press S while right mouse click-drag to integrate to a mass spectrum");
 		AbstractPlotWidget::registerQtKeyCode(Qt::Key_D,
@@ -291,18 +291,6 @@ namespace msXpSmineXpert
 		}
 
 
-	/*/js/
-	 * ColorMapPlotWidget.integrateToRt(dtRangeStart, dtRangeEnd, mzRangeStart, mzRangeEnd)
-	 *
-	 * Starts an integration of mass spectra data to a XIC chromatogram limiting
-	 * the data ranges specified with the numerical arguments.
-	 *
-	 * dtRange(Start | End) drift time range values
-	 * mzRange(Start | End) m/z range values
-	 *
-	 * This function creates a new plot widget to display the obtained results.
-	 */
-
 	//! Integrate data to a retention time (TIC/XIC) chromatogram
 	/*!
 
@@ -332,6 +320,38 @@ namespace msXpSmineXpert
 		}
 
 
+	/*/js/
+	 * ColorMapPlotWidget.jsIntegrateToRt(dtRangeStart, dtRangeEnd, mzRangeStart, mzRangeEnd)
+	 *
+	 * Starts an integration of mass spectra data to a XIC chromatogram limiting
+	 * the data ranges specified with the numerical arguments.
+	 *
+	 * dtRange(Start | End) drift time range values
+	 * mzRange(Start | End) m/z range values
+	 *
+	 * This function creates a new plot widget to display the obtained results.
+	 */
+	void
+		ColorMapPlotWidget::jsIntegrateToRt(double dtRangeStart, double dtRangeEnd,
+				double mzRangeStart, double mzRangeEnd)
+
+		{
+			History localHistory = m_history;
+			HistoryItem *histItem = new HistoryItem;
+
+			histItem->newIntegrationRange(IntegrationType::DTMZ_DT_TO_RT,
+					dtRangeStart, dtRangeEnd);
+
+			histItem->newIntegrationRange(IntegrationType::DTMZ_MZ_TO_RT,
+					mzRangeStart, mzRangeEnd);
+
+			// Aggreate the new item to the local history copy we made.
+			localHistory.appendHistoryItem(histItem);
+
+			emit jsNewTicChromatogram(mp_massSpecDataSet,
+					"Calculating extracted ion chromatogram.", localHistory, m_plottingColor);
+		}
+
 	//! Integrate data to a mass spectrum
 	/*!
 
@@ -339,17 +359,6 @@ namespace msXpSmineXpert
 		ranges on both the x and y axes.
 
 */
-	/*/js/
-	 * ColorMapPlotWidget.integrateToMz(dtRangeStart, dtRangeEnd, mzRangeStart, mzRangeEnd)
-	 *
-	 * Starts an integration of mass spectra data to a mass spectrum limiting the
-	 * data ranges specified with the numerical arguments.
-	 *
-	 * dtRange(Start | End) drift time range values
-	 * mzRange(Start | End) m/z range values
-	 *
-	 * This function creates a new plot widget to display the obtained results.
-	 */
 	void
 		ColorMapPlotWidget::integrateToMz(double dtRangeStart, double dtRangeEnd,
 				double mzRangeStart, double mzRangeEnd)
@@ -397,17 +406,10 @@ namespace msXpSmineXpert
 		}
 
 
-	//! Integrate data to a drift spectrum
-	/*!
-
-		The data to be integrated are bordered by the parameters that describe data
-		ranges on both the x and y axes.
-
-*/
 	/*/js/
-	 * ColorMapPlotWidget.integrateToDt(dtRangeStart, dtRangeEnd, mzRangeStart, mzRangeEnd)
+	 * ColorMapPlotWidget.jsIntegrateToMz(dtRangeStart, dtRangeEnd, mzRangeStart, mzRangeEnd)
 	 *
-	 * Starts an integration of mass spectra data to a drift spectrum limiting the
+	 * Starts an integration of mass spectra data to a mass spectrum limiting the
 	 * data ranges specified with the numerical arguments.
 	 *
 	 * dtRange(Start | End) drift time range values
@@ -415,6 +417,60 @@ namespace msXpSmineXpert
 	 *
 	 * This function creates a new plot widget to display the obtained results.
 	 */
+	void
+		ColorMapPlotWidget::jsIntegrateToMz(double dtRangeStart, double dtRangeEnd,
+				double mzRangeStart, double mzRangeEnd)
+		{
+			History localHistory = m_history;
+
+			// The color map plot widget serves as a starting point for data
+			// exploration exactly as the TIC chromatogram plot widget that is created
+			// right after having loaded mass data. Thus, when integrating to a mass
+			// spectrum, we need to comply with the mz integration parameters that
+			// were set for that TIC chrom widget (so-called root widget for a given
+			// mass data file). Let's get that widget and obtain from it a copy of the
+			// mz integration parameters.
+
+			ColorMapWnd *parentWnd = static_cast<ColorMapWnd *>(mp_parentWnd);
+			MainWindow *mainWindow = static_cast<MainWindow *>(parentWnd->parent());
+
+			// This is merely a holder for a result of the call below
+			DataPlotWidgetRelation *plotWidgetRelation = Q_NULLPTR;
+
+			AbstractPlotWidget *rootPlotWidget =
+				mainWindow->m_dataPlotWidgetRelationer.rootPlotWidget(this, &plotWidgetRelation);
+
+			if(rootPlotWidget == Q_NULLPTR)
+				qFatal("Fatal error at %s@%d -- %s(). "
+						"Cannot be that a color map widget has no root TIC chrom plot widget."
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__);
+
+			MzIntegrationParams params = static_cast<TicChromPlotWidget *>(rootPlotWidget)->mzIntegrationParams();
+			localHistory.setMzIntegrationParams(params);
+			HistoryItem *histItem = new HistoryItem;
+
+			histItem->newIntegrationRange(IntegrationType::DTMZ_DT_TO_MZ,
+					dtRangeStart, dtRangeEnd);
+
+			histItem->newIntegrationRange(IntegrationType::DTMZ_MZ_TO_MZ,
+					mzRangeStart, mzRangeEnd);
+
+			// Aggreate the new item to the local history copy we made.
+			localHistory.appendHistoryItem(histItem);
+
+			emit jsNewMassSpectrum(mp_massSpecDataSet,
+					"Calculating mass spectrum.", localHistory, m_plottingColor);
+		}
+
+
+
+	//! Integrate data to a drift spectrum
+	/*!
+
+		The data to be integrated are bordered by the parameters that describe data
+		ranges on both the x and y axes.
+		*/
 	void
 		ColorMapPlotWidget::integrateToDt(double dtRangeStart, double dtRangeEnd,
 				double mzRangeStart, double mzRangeEnd)
@@ -439,6 +495,41 @@ namespace msXpSmineXpert
 		}
 
 
+	/*/js/
+	 * ColorMapPlotWidget.jsIntegrateToDt(dtRangeStart, dtRangeEnd, mzRangeStart, mzRangeEnd)
+	 *
+	 * Starts an integration of mass spectra data to a drift spectrum limiting the
+	 * data ranges specified with the numerical arguments.
+	 *
+	 * dtRange(Start | End) drift time range values
+	 * mzRange(Start | End) m/z range values
+	 *
+	 * This function creates a new plot widget to display the obtained results.
+	 */
+	void
+		ColorMapPlotWidget::jsIntegrateToDt(double dtRangeStart, double dtRangeEnd,
+				double mzRangeStart, double mzRangeEnd)
+		{
+			History localHistory = m_history;
+			HistoryItem *histItem = new HistoryItem;
+
+			histItem->newIntegrationRange(IntegrationType::DTMZ_DT_TO_DT,
+					dtRangeStart, dtRangeEnd);
+
+			histItem->newIntegrationRange(IntegrationType::DTMZ_MZ_TO_DT,
+					mzRangeStart, mzRangeEnd);
+
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__
+			//<< "histItem:" << histItem->asText();
+
+			// Aggreate the new item to the local history copy we made.
+			localHistory.appendHistoryItem(histItem);
+
+			emit jsNewDriftSpectrum(mp_massSpecDataSet,
+					"Calculating drift spectrum.", localHistory, m_plottingColor);
+		}
+
+
 	//! Integrate data to a single TIC intensity value
 	/*!
 
@@ -447,19 +538,7 @@ namespace msXpSmineXpert
 
 		This is not a conventional integration, because it does not produce any
 		graph, it only produces a single TIC intensity value.
-
-*/
-	/*/js/
-	 * ColorMapPlotWidget.integrateToTicIntensity(dtRangeStart, dtRangeEnd, mzRangeStart, mzRangeEnd)
-	 *
-	 * Starts an integration of mass spectra data to a TIC intensity single value
-	 * limiting the data ranges specified with the numerical arguments.
-	 *
-	 * dtRange(Start | End) drift time range values
-	 * mzRange(Start | End) m/z range values
-	 *
-	 * The TIC intensity value is returned
-	 */
+		*/
 	void
 		ColorMapPlotWidget::integrateToTicIntensity(double dtRangeStart, double dtRangeEnd,
 				double mzRangeStart, double mzRangeEnd)
@@ -505,12 +584,72 @@ namespace msXpSmineXpert
 		}
 
 
+	/*/js/
+	 * ColorMapPlotWidget.jsIntegrateToTicIntensity(dtRangeStart, dtRangeEnd, mzRangeStart, mzRangeEnd)
+	 *
+	 * Starts an integration of mass spectra data to a TIC intensity single value
+	 * limiting the data ranges specified with the numerical arguments.
+	 *
+	 * dtRange(Start | End) drift time range values
+	 * mzRange(Start | End) m/z range values
+	 *
+	 * The TIC intensity value is returned
+	 */
+	double
+		ColorMapPlotWidget::jsIntegrateToTicIntensity(double dtRangeStart, double dtRangeEnd,
+				double mzRangeStart, double mzRangeEnd)
+		{
+			History localHistory = m_history;
+			HistoryItem *histItem = new HistoryItem;
+
+			histItem->newIntegrationRange(IntegrationType::DTMZ_DT_TO_TIC_INT,
+					dtRangeStart, dtRangeEnd);
+
+			histItem->newIntegrationRange(IntegrationType::DTMZ_MZ_TO_TIC_INT,
+					mzRangeStart, mzRangeEnd);
+
+			// Aggreate the new item to the local history copy we made.
+			localHistory.appendHistoryItem(histItem);
+
+			ColorMapWnd *parentWnd = static_cast<ColorMapWnd *>(mp_parentWnd);
+
+
+			// Capture immediately the text that is located in the status bar
+			// because if the computation is long that text will have disappeared
+			// and we won't be able to show it in the TIC int text.
+
+			QString currentMessage = parentWnd->statusBar()->currentMessage();
+
+			QApplication::setOverrideCursor(QCursor(Qt::BusyCursor));
+
+			MassDataIntegrator integrator(mp_massSpecDataSet, localHistory);
+
+			integrator.integrateToTicIntensity();
+
+			m_lastTicIntensity = integrator.ticIntensity();
+
+			QApplication::restoreOverrideCursor();
+
+			if(currentMessage.isEmpty())
+				parentWnd->statusBar()->showMessage(QString("dt range [%1-%2] ; m/z range [%3-%4]: TIC I = %5")
+						.arg(dtRangeStart, 0, 'f', 3)
+						.arg(dtRangeEnd, 0, 'f', 3)
+						.arg(mzRangeStart, 0, 'f', 3)
+						.arg(mzRangeEnd, 0, 'f', 3)
+						.arg(m_lastTicIntensity, 0, 'g', 3));
+			else
+				parentWnd->statusBar()->showMessage(currentMessage +
+						QString(" ; (Tic I = %1)").arg(m_lastTicIntensity, 0, 'g', 3));
+
+			return m_lastTicIntensity;
+		}
+
+
 	/*/js/
 	 * ColorMapPlotWidget.transposeAxes()
 	 *
 	 * Transpose the axes of this color map plot widget
 	 */
-
 	//! Transpose the axes such that the dt axis takes the place of the m/z axis.
 	void
 		ColorMapPlotWidget::transposeAxes()
@@ -688,15 +827,12 @@ namespace msXpSmineXpert
 		}
 
 
-
 	/*/js/
 	 * ColorMapPlotWidget.jsSetMzIntegrationParams(mzIntegrationParams)
 	 *
-	 * Set the MzIntegrationParams object passed as parameter to this color map
-	 * plot widget.
-	 *
-	 * These parameters are taken into account for the integrations to a mass
-	 * spectrum.
+	 * Set the m/z integration parameters object passed as parameter to this plot
+	 * widget so that they are taken into account for the next integrations to a
+	 * mass spectrum.
 	 */
 	void
 		ColorMapPlotWidget::jsSetMzIntegrationParams()
