@@ -54,6 +54,7 @@
 namespace msXpSmineXpert
 {
 
+
 	//! Initialize the widget count to 0.
 	int ColorMapWnd::widgetCounter = 0;
 
@@ -406,16 +407,31 @@ namespace msXpSmineXpert
 					mainWindow->mp_massSpecWnd,
 					&MassSpecWnd::newMassSpectrum);
 
+			connect(static_cast<ColorMapPlotWidget *>(widget),
+					&ColorMapPlotWidget::jsNewMassSpectrum,
+					mainWindow->mp_massSpecWnd,
+					&MassSpecWnd::jsNewMassSpectrum);
+
 			connect(static_cast<ColorMapPlotWidget *>(widget),
 					&ColorMapPlotWidget::newDriftSpectrum,
 					mainWindow->mp_driftSpecWnd,
 					&DriftSpecWnd::newDriftSpectrum);
 
+			connect(static_cast<ColorMapPlotWidget *>(widget),
+					&ColorMapPlotWidget::jsNewDriftSpectrum,
+					mainWindow->mp_driftSpecWnd,
+					&DriftSpecWnd::jsNewDriftSpectrum);
+
 			connect(static_cast<ColorMapPlotWidget *>(widget),
 					&ColorMapPlotWidget::newTicChromatogram,
 					mainWindow->mp_ticChromWnd,
 					&TicChromWnd::newTicChromatogram);
 
+			connect(static_cast<ColorMapPlotWidget *>(widget),
+					&ColorMapPlotWidget::jsNewTicChromatogram,
+					mainWindow->mp_ticChromWnd,
+					&TicChromWnd::jsNewTicChromatogram);
+
 			connect(static_cast<ColorMapPlotWidget *>(widget),
 					&ColorMapPlotWidget::ticIntensitySignal,
 					this,
@@ -434,6 +450,45 @@ namespace msXpSmineXpert
 		}
 
 
+	void
+		ColorMapWnd::jsInitialColorMap(const MassSpecDataSet *massSpecDataSet,
+				AbstractPlotWidget *originPlotWidget,
+				const QColor &color)
+		{
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
+
+			if(massSpecDataSet == Q_NULLPTR)
+				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
+
+			MainWindow *mainWindow = static_cast<MainWindow *>(parent());
+			mainWindow->logConsoleMessage("Computing MZ=DT color map");
+
+			// Make sure the cancel button is visible.
+			mp_statusBarCancelPushButton->setVisible(true);
+			QApplication::processEvents();
+
+			MassDataIntegrator *integrator = new MassDataIntegrator(massSpecDataSet);
+
+			connect(integrator,
+					&MassDataIntegrator::updateFeedbackSignal,
+					this,
+					&AbstractMultiPlotWnd::updateFeedback);
+
+			connect(this,
+					&AbstractMultiPlotWnd::cancelOperationSignal,
+					integrator,
+					&MassDataIntegrator::cancelOperation);
+
+			// Fill-in the dt/mass spectrum hash. This is the hardest computing part
+			// of the whole color map creation task.
+
+			integrator->fillInDtMzHash();
+
+			// Now go on with non-threaded function that will relay to the mainwindow.
+			initialColorMapDone(integrator, originPlotWidget, color);
+		}
+
+
 	void
 		ColorMapWnd::ticIntensity(const MassSpecDataSet *massSpecDataSet,
 				const QString &msg, History history)
