@@ -88,7 +88,7 @@ namespace msXpSmineXpert
 			desc, massSpecDataSet, fileName, isMultiGraph}
 	{
 		AbstractPlotWidget::registerQtKeyCode(Qt::Key_R,
-				"Press T while right mouse click-drag to integrate to a XIC chromatogram");
+				"Press R while right mouse click-drag to integrate to a XIC chromatogram");
 		AbstractPlotWidget::registerQtKeyCode(Qt::Key_S,
 				"Press S while right mouse click-drag to integrate to a mass spectrum");
 		AbstractPlotWidget::registerQtKeyCode(Qt::Key_I,
@@ -384,18 +384,6 @@ namespace msXpSmineXpert
 		}
 
 
-	/*/js/
-	 * DriftSpecPlotWidget.integrateToMz(lower, upper)
-	 *
-	 * Starts an integration of mass spectra data to a mass spectrum limiting the
-	 * data range specified with the numerical arguments.
-	 *
-	 * lower, upper: retention time values limiting the integration. If no values
-	 * are provided, there is no limitation to the integration.
-	 *
-	 * This function creates a new plot widget to display the obtained results.
-	 */
-
 	//! Integrate data to a mass spectrum with drift time range [\p lower -- \p upper ].
 	void
 		DriftSpecPlotWidget::integrateToMz(double lower, double upper)
@@ -431,9 +419,9 @@ namespace msXpSmineXpert
 
 
 	/*/js/
-	 * DriftSpecPlotWidget.integrateToRt(lower, upper)
+	 * DriftSpecPlotWidget.jsIntegrateToMz(lower, upper)
 	 *
-	 * Starts an integration of mass spectra data to a XIC chromatogram limiting the
+	 * Starts an integration of mass spectra data to a mass spectrum limiting the
 	 * data range specified with the numerical arguments.
 	 *
 	 * lower, upper: retention time values limiting the integration. If no values
@@ -441,6 +429,38 @@ namespace msXpSmineXpert
 	 *
 	 * This function creates a new plot widget to display the obtained results.
 	 */
+	void
+		DriftSpecPlotWidget::jsIntegrateToMz(double lower, double upper)
+		{
+			// Get the pointer to the x-axis (key axis).
+
+			QCPAxis *xAxis = graph()->keyAxis();
+
+			double rangeStart = lower;
+			if(qIsNaN(rangeStart))
+			{
+				rangeStart = xAxis->range().lower;
+			}
+
+			double rangeEnd = upper;
+			if(qIsNaN(rangeEnd))
+			{
+				rangeEnd = xAxis->range().upper;
+			}
+
+			History localHistory = m_history;
+			HistoryItem *histItem = new HistoryItem;
+			histItem->newIntegrationRange(IntegrationType::DT_TO_MZ, rangeStart, rangeEnd);
+
+			// Aggreate the new item to the history we got as a parameter and that
+			// we copied into localHistory.
+			localHistory.appendHistoryItem(histItem);
+
+			emit jsNewMassSpectrum(mp_massSpecDataSet,
+					"Calculating mass spectrum.", localHistory,
+					graph()->pen().color());
+		}
+
 
 	//! Integrate data to a TIC chromatogram (XIC) with drift time range [\p lower -- \p upper ].
 	void
@@ -477,16 +497,48 @@ namespace msXpSmineXpert
 
 
 	/*/js/
-	 * DriftSpecPlotWidget.integrateToTicIntensity(lower, upper)
+	 * DriftSpecPlotWidget.jsIntegrateToRt(lower, upper)
 	 *
-	 * Starts an integration of mass spectra data to a TIC intensity single value
-	 * limiting the data range specified with the numerical arguments.
+	 * Starts an integration of mass spectra data to a XIC chromatogram limiting the
+	 * data range specified with the numerical arguments.
 	 *
 	 * lower, upper: retention time values limiting the integration. If no values
 	 * are provided, there is no limitation to the integration.
 	 *
-	 * The TIC intensity value is returned
+	 * This function creates a new plot widget to display the obtained results.
 	 */
+	void
+		DriftSpecPlotWidget::jsIntegrateToRt(double lower, double upper)
+		{
+			// Get the pointer to the x-axis (key axis).
+
+			QCPAxis *xAxis = graph()->keyAxis();
+
+			double rangeStart = lower;
+			if(qIsNaN(rangeStart))
+			{
+				rangeStart = xAxis->range().lower;
+			}
+
+			double rangeEnd = upper;
+			if(qIsNaN(rangeEnd))
+			{
+				rangeEnd = xAxis->range().upper;
+			}
+
+			History localHistory = m_history;
+			HistoryItem *histItem = new HistoryItem;
+			histItem->newIntegrationRange(IntegrationType::DT_TO_RT, rangeStart, rangeEnd);
+
+			// Aggreate the new item to the history we got as a parameter and that
+			// we copied into localHistory.
+			localHistory.appendHistoryItem(histItem);
+
+			emit jsNewTicChromatogram(mp_massSpecDataSet,
+					"Calculating extracted ion chromatogram.", localHistory,
+					graph()->pen().color());
+		}
+
 
 	//! Integrate data to a single TIC intensity value with drift time range [\p lower -- \p upper ].
 	void
@@ -583,6 +635,122 @@ namespace msXpSmineXpert
 		}
 
 
+	/*/js/
+	 * DriftSpecPlotWidget.jsIntegrateToTicIntensity(lower, upper)
+	 *
+	 * Starts an integration of mass spectra data to a TIC intensity single value
+	 * limiting the data range specified with the numerical arguments.
+	 *
+	 * lower, upper: retention time values limiting the integration. If no values
+	 * are provided, there is no limitation to the integration.
+	 *
+	 * The TIC intensity value is returned
+	 */
+	double
+		DriftSpecPlotWidget::jsIntegrateToTicIntensity(double lower, double upper)
+		{
+			if(m_isMultiGraph)
+				// We cannot perform the action, because this plot widget has not mass
+				// spec data set pointer, it is a graph-only plot widget to display all
+				// the graphs overlaid.
+				return 0;
+
+			// Get the pointer to the x-axis (key axis).
+
+			QCPAxis *xAxis = graph()->keyAxis();
+
+			double rangeStart = lower;
+			if(qIsNaN(rangeStart))
+			{
+				rangeStart = xAxis->range().lower;
+			}
+
+			double rangeEnd = upper;
+			if(qIsNaN(rangeEnd))
+			{
+				rangeEnd = xAxis->range().upper;
+			}
+
+			// Reset the axis range data because we may return prematurely and we want
+			// to craft a stanza with proper values (even if they are qINan()).
+			m_keyRangeStart = qSNaN();
+			m_keyRangeEnd = qSNaN();
+
+			// Also reset the other datum that might hold invalid values.
+			m_lastTicIntensity = qSNaN();
+
+			if(rangeStart == rangeEnd)
+			{
+				return false;
+			}
+
+			// Slot for sorting stuff.
+			double tempVal;
+
+			// Set the values in sorted order for later stanza crafting.
+			if(rangeStart > rangeEnd)
+			{
+				tempVal = rangeStart;
+				rangeStart = rangeEnd;
+				rangeStart = tempVal;
+			}
+
+			History localHistory = m_history;
+			HistoryItem *histItem = new HistoryItem;
+			histItem->newIntegrationRange(IntegrationType::DT_TO_TIC_INT, rangeStart, rangeEnd);
+
+			// At this point store the range data so that the user may use it in
+			// analysis reporting.
+			m_keyRangeStart = rangeStart;
+			m_keyRangeEnd = rangeEnd;
+
+			// Aggreate the new item to the history.
+			localHistory.appendHistoryItem(histItem);
+
+			DriftSpecWnd *parentWnd = static_cast<DriftSpecWnd *>(mp_parentWnd);
+
+			// Capture immediately the text that is located in the status bar
+			// because if the computation is long that text will have disappeared
+			// and we won't be able to show it in the TIC int text.
+
+			QString currentMessage = parentWnd->statusBar()->currentMessage();
+
+			QApplication::setOverrideCursor(QCursor(Qt::BusyCursor));
+
+			// Sanity check. It is not possible that this plot widget is not
+			// multi-graph and that at the same time, the mass spec data set pointer
+			// is nullptr.
+
+			if(!m_isMultiGraph && mp_massSpecDataSet == Q_NULLPTR)
+				qFatal("Fatal error at %s@%d -- %s(). "
+						"Programming error."
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__);
+
+			MassDataIntegrator integrator(mp_massSpecDataSet, localHistory);
+
+			integrator.integrateToTicIntensity();
+
+			m_lastTicIntensity = integrator.ticIntensity();
+
+			QApplication::restoreOverrideCursor();
+
+			if(currentMessage.isEmpty())
+				parentWnd->statusBar()->showMessage(QString("range [%1-%2]: TIC I = %3")
+						.arg(m_keyRangeStart, 0, 'f', 3)
+						.arg(m_keyRangeEnd, 0, 'f', 3)
+						.arg(m_lastTicIntensity, 0, 'g', 3));
+			else
+				parentWnd->statusBar()->showMessage(currentMessage +
+						QString(" ; range [%1-%2]: TIC I = %3")
+						.arg(m_keyRangeStart, 0, 'g', 3)
+						.arg(m_keyRangeEnd, 0, 'g', 3)
+						.arg(m_lastTicIntensity, 0, 'g', 3));
+
+			return m_lastTicIntensity;
+		}
+
+
 	/*/js/
 	 * DriftSpecPlotWidget.newPlot(trace)
 	 *
@@ -1224,6 +1392,13 @@ namespace msXpSmineXpert
 		}
 
 
+	/*/js/
+	 * TicChromPlotWidget.jsSetMzIntegrationParams(mzIntegrationParams)
+	 *
+	 * Set the m/z integration parameters object passed as parameter to this plot
+	 * widget so that they are taken into account for the next integrations to a
+	 * mass spectrum.
+	 */
 	void
 		DriftSpecPlotWidget::jsSetMzIntegrationParams()
 		{
@@ -1275,6 +1450,15 @@ namespace msXpSmineXpert
 		}
 
 
+	/*/js/
+	 * TicChromPlotWidget.jsMzIntegrationParams()
+	 *
+	 * Return the MzIntegrationParams object currently set for this color map
+	 * plot widget.
+	 *
+	 * These parameters are taken into account for the integrations to a mass
+	 * spectrum.
+	 */
 	QScriptValue
 		DriftSpecPlotWidget::jsMzIntegrationParams() const
 		{
