@@ -106,6 +106,7 @@ namespace msXpSmineXpert
 	}
 
 
+	//! Create the contextual menu.
 	QMenu *
 		MassSpecPlotWidget::createContextMenu()
 		{
@@ -347,8 +348,8 @@ namespace msXpSmineXpert
 			m_keyRangeEnd = qSNaN();
 
 			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-				//<< "m_xRangeMin:" << m_xRangeMin
-				//<< "m_xRangeMax:" << m_xRangeMax;
+			//<< "m_xRangeMin:" << m_xRangeMin
+			//<< "m_xRangeMax:" << m_xRangeMax;
 
 			if(m_xRangeMax == m_xRangeMin)
 			{
@@ -764,18 +765,6 @@ namespace msXpSmineXpert
 		}
 
 
-	/*/js/
-	 * MassSpecPlotWidget.integrateToDt(lower, upper)
-	 *
-	 * Starts an integration of mass spectra data to a drift spectrum limiting the
-	 * data range specified with the numerical arguments.
-	 *
-	 * lower, upper: retention time values limiting the integration. If no values
-	 * are provided, there is no limitation to the integration.
-	 *
-	 * This function creates a new plot widget to display the obtained results.
-	 */
-
 	//! Perform a ranged [\p lower -- \p upper] data integration to a drift spectrum.
 	void
 		MassSpecPlotWidget::integrateToDt(double lower, double upper)
@@ -810,9 +799,9 @@ namespace msXpSmineXpert
 
 
 	/*/js/
-	 * MassSpecPlotWidget.integrateToRt(lower, upper)
+	 * MassSpecPlotWidget.jsIntegrateToDt(lower, upper)
 	 *
-	 * Starts an integration of mass spectra data to a XIC chromatogram limiting the
+	 * Starts an integration of mass spectra data to a drift spectrum limiting the
 	 * data range specified with the numerical arguments.
 	 *
 	 * lower, upper: retention time values limiting the integration. If no values
@@ -820,6 +809,37 @@ namespace msXpSmineXpert
 	 *
 	 * This function creates a new plot widget to display the obtained results.
 	 */
+	void
+		MassSpecPlotWidget::jsIntegrateToDt(double lower, double upper)
+		{
+			// Get the pointer to the x-axis (key axis).
+
+			QCPAxis *xAxis = graph()->keyAxis();
+
+			double rangeStart = lower;
+			if(qIsNaN(rangeStart))
+			{
+				rangeStart = xAxis->range().lower;
+			}
+
+			double rangeEnd = upper;
+
+			if(qIsNaN(rangeEnd))
+			{
+				rangeEnd = xAxis->range().upper;
+			}
+
+			History localHistory = m_history;
+			HistoryItem *histItem = new HistoryItem;
+			histItem->newIntegrationRange(IntegrationType::MZ_TO_DT, rangeStart, rangeEnd);
+
+			// Aggreate the new item to the local history copy we made.
+			localHistory.appendHistoryItem(histItem);
+
+			emit jsNewDriftSpectrum(mp_massSpecDataSet, "Calculating drift spectrum.",
+					localHistory, m_plottingColor);
+		}
+
 
 	//! Perform a ranged [\p lower -- \p upper] data integration to a TIC chromatogram.
 	void
@@ -858,16 +878,50 @@ namespace msXpSmineXpert
 
 
 	/*/js/
-	 * MassSpecPlotWidget.integrateToTicIntensity(lower, upper)
+	 * MassSpecPlotWidget.jsIntegrateToRt(lower, upper)
 	 *
-	 * Starts an integration of mass spectra data to a TIC intensity single value
-	 * limiting the data range specified with the numerical arguments.
+	 * Starts an integration of mass spectra data to a XIC chromatogram limiting the
+	 * data range specified with the numerical arguments.
 	 *
 	 * lower, upper: retention time values limiting the integration. If no values
 	 * are provided, there is no limitation to the integration.
 	 *
-	 * The TIC intensity value is returned
+	 * This function creates a new plot widget to display the obtained results.
 	 */
+	void
+		MassSpecPlotWidget::jsIntegrateToRt(double lower, double upper)
+		{
+			// Get the pointer to the x-axis (key axis).
+
+			QCPAxis *xAxis = graph()->keyAxis();
+
+			double rangeStart = lower;
+			if(qIsNaN(rangeStart))
+			{
+				rangeStart = xAxis->range().lower;
+			}
+
+			double rangeEnd = upper;
+
+			if(qIsNaN(rangeEnd))
+			{
+				rangeEnd = xAxis->range().upper;
+			}
+
+			History localHistory = m_history;
+			HistoryItem *histItem = new HistoryItem;
+			histItem->newIntegrationRange(IntegrationType::MZ_TO_RT, rangeStart, rangeEnd);
+
+			// Aggreate the new item to the local history copy we made.
+			localHistory.appendHistoryItem(histItem);
+
+			// The signal is emitted, but the connection to the receiver exists only
+			// if this plot widget is NOT multi-graph. So, even if mp_massSpecDataSet
+			// is nullptr, there is no risk.
+			emit jsNewTicChromatogram(mp_massSpecDataSet, "Calculating extracted ion chromatogram.",
+					localHistory, m_plottingColor);
+		}
+
 
 	//! Perform a ranged [\p lower -- \p upper] data integration to a single TIC intensity value.
 	void
@@ -963,6 +1017,136 @@ namespace msXpSmineXpert
 		}
 
 
+	/*/js/
+	 * MassSpecPlotWidget.jsIntegrateToTicIntensity(lower, upper)
+	 *
+	 * Starts an integration of mass spectra data to a TIC intensity single value
+	 * limiting the data range specified with the numerical arguments.
+	 *
+	 * lower, upper: retention time values limiting the integration. If no values
+	 * are provided, there is no limitation to the integration.
+	 *
+	 * The TIC intensity value is returned
+	 */
+	double
+		MassSpecPlotWidget::jsIntegrateToTicIntensity(double lower, double upper)
+		{
+			if(m_isMultiGraph)
+				// We cannot perform the action, because this plot widget has not mass
+				// spec data set pointer, it is a graph-only plot widget to display all
+				// the graphs overlaid.
+				return 0;
+
+			// Get the pointer to the x-axis (key axis).
+
+			QCPAxis *xAxis = graph()->keyAxis();
+
+			double rangeStart = lower;
+			if(qIsNaN(rangeStart))
+			{
+				rangeStart = xAxis->range().lower;
+			}
+
+			double rangeEnd = upper;
+			if(qIsNaN(rangeEnd))
+			{
+				rangeEnd = xAxis->range().upper;
+			}
+
+			// Reset the axis range data because we may return prematurely and we want
+			// to craft a stanza with proper values (even if they are qINan()).
+			m_keyRangeStart = qSNaN();
+			m_keyRangeEnd = qSNaN();
+
+			// Also reset the other datum that might hold invalid values.
+			m_lastTicIntensity = qSNaN();
+
+			if(rangeStart == rangeEnd)
+			{
+				return false;
+			}
+
+			// Slot for sorting stuff.
+			double tempVal;
+
+			// Set the values in sorted order for later stanza crafting.
+			if(rangeStart > rangeEnd)
+			{
+				tempVal = rangeStart;
+				rangeStart = rangeEnd;
+				rangeStart = tempVal;
+			}
+
+			History localHistory = m_history;
+			HistoryItem *histItem = new HistoryItem;
+			histItem->newIntegrationRange(IntegrationType::MZ_TO_TIC_INT, rangeStart, rangeEnd);
+
+			// At this point store the range data so that the user may use it in
+			// analysis reporting.
+			m_keyRangeStart = rangeStart;
+			m_keyRangeEnd = rangeEnd;
+
+			// Aggreate the new item to the local history copy we made.
+			localHistory.appendHistoryItem(histItem);
+
+			MassSpecWnd *parentWnd = static_cast<MassSpecWnd *>(mp_parentWnd);
+
+			// Capture immediately the text that is located in the status bar
+			// because if the computation is long that text will have disappeared
+			// and we won't be able to show it in the TIC int text.
+
+			QString currentMessage = parentWnd->statusBar()->currentMessage();
+
+			QApplication::setOverrideCursor(QCursor(Qt::BusyCursor));
+
+			// Sanity check. It is not possible that this plot widget is not
+			// multi-graph and that at the same time, the mass spec data set pointer
+			// is nullptr.
+
+			if(!m_isMultiGraph && mp_massSpecDataSet == Q_NULLPTR)
+				qFatal("Fatal error at %s@%d -- %s(). "
+						"Programming error."
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__);
+
+			MassDataIntegrator integrator(mp_massSpecDataSet, localHistory);
+
+			integrator.integrateToTicIntensity();
+
+			m_lastTicIntensity = integrator.ticIntensity();
+
+			QApplication::restoreOverrideCursor();
+
+			if(currentMessage.isEmpty())
+				parentWnd->statusBar()->showMessage(QString("range [%1-%2]: TIC I = %3")
+						.arg(m_keyRangeStart, 0, 'f', 3)
+						.arg(m_keyRangeEnd, 0, 'f', 3)
+						.arg(m_lastTicIntensity, 0, 'g', 3));
+			else
+				parentWnd->statusBar()->showMessage(currentMessage +
+						QString(" ; range [%1-%2]: TIC I = %3")
+						.arg(m_keyRangeStart, 0, 'f', 3)
+						.arg(m_keyRangeEnd, 0, 'f', 3)
+						.arg(m_lastTicIntensity, 0, 'g', 3));
+
+			return m_lastTicIntensity;
+		}
+
+
+	/*/js/
+	 * MassSpecPlotWidget.massSpectrum(lower, upper)
+	 *
+	 * Creates a new <MassSpectrum> object limiting the data to the lower and
+	 * upper range limits. The data used to craft the new MassSpectrum are this
+	 * plot widget data. That is, the <MassSpectrum> object is not created by
+	 * looking into the internal mass spectral data set.
+	 *
+	 * lower, upper: m/z values limiting the integration. If no values
+	 * are provided, there is no limitation to the integration and all the points
+	 * in this plot widget are used.
+	 *
+	 * Return a new MassSpectrum object.
+	 */
 	//! Return a MassSpectrum crafted from the plot data.
 	msXpSlibmass::MassSpectrum
 		MassSpecPlotWidget::massSpectrum(double lower, double upper)
@@ -1624,5 +1808,4 @@ namespace msXpSmineXpert
 		}
 
 
-
 } // namespace msXpSmineXpert
