@@ -108,6 +108,7 @@ namespace msXpSmineXpert
 	}
 
 
+	//! Create the contextual menus.
 	QMenu *
 		TicChromPlotWidget::createContextMenu()
 		{
@@ -349,6 +350,7 @@ namespace msXpSmineXpert
 		}
 
 
+	//! Set focus to \c this widget.
 	void
 		TicChromPlotWidget::setFocus()
 		{
@@ -373,8 +375,7 @@ namespace msXpSmineXpert
 		This function checks for the pressed keyboard key code and, depending on
 		that key code, triggers specific actions, like integrating data to drift
 		spectrum or to retention time (XIC) or to single TIC intensity value.
-
-*/
+		*/
 	void
 		TicChromPlotWidget::mouseReleaseHandledEvent(QMouseEvent *event)
 		{
@@ -427,18 +428,6 @@ namespace msXpSmineXpert
 		}
 
 
-	/*/js/
-	 * TicChromPlotWidget.integrateToMz(lower, upper)
-	 *
-	 * Starts an integration of mass spectra data to a mass spectrum limiting the
-	 * data range specified with the numerical arguments.
-	 *
-	 * lower, upper: retention time values limiting the integration. If no values
-	 * are provided, there is no limitation to the integration.
-	 *
-	 * This function creates a new plot widget to display the obtained results.
-	 */
-
 	//! Perform a ranged [\p lower -- \p upper] data integration to a mass spectrum.
 	void
 		TicChromPlotWidget::integrateToMz(double lower, double upper)
@@ -481,9 +470,9 @@ namespace msXpSmineXpert
 
 
 	/*/js/
-	 * TicChromPlotWidget.integrateToDt(lower, upper)
+	 * TicChromPlotWidget.jsIntegrateToMz(lower, upper)
 	 *
-	 * Starts an integration of mass spectra data to a drift spectrum limiting the
+	 * Starts an integration of mass spectra data to a mass spectrum limiting the
 	 * data range specified with the numerical arguments.
 	 *
 	 * lower, upper: retention time values limiting the integration. If no values
@@ -492,6 +481,47 @@ namespace msXpSmineXpert
 	 * This function creates a new plot widget to display the obtained results.
 	 */
 
+	//! Perform a ranged [\p lower -- \p upper] data integration to a mass spectrum.
+	void
+		TicChromPlotWidget::jsIntegrateToMz(double lower, double upper)
+		{
+			// Get the pointer to the x-axis (key axis).
+
+			QCPAxis *xAxis = graph()->keyAxis();
+
+			double rangeStart = lower;
+			if(qIsNaN(rangeStart))
+			{
+				rangeStart = xAxis->range().lower;
+			}
+
+			double rangeEnd = upper;
+
+			if(qIsNaN(rangeEnd))
+			{
+				rangeEnd = xAxis->range().upper;
+			}
+
+			// The history has by definition the bin specifications, which we'll use
+			// to perform the integrations. This is only true when integrating to
+			// MZ, because the result will be a mass spectrum plot. When integrating
+			// to DT or TICintensity, then no problem: we are working all along with
+			// TIC values and TIC values do not need bins to be properly displayed
+			// into a mass spectrum.
+
+			History localHistory = m_history;
+
+			HistoryItem *histItem = new HistoryItem;
+			histItem->newIntegrationRange(IntegrationType::RT_TO_MZ, rangeStart, rangeEnd);
+
+			// Aggreate the new item to the history.
+			localHistory.appendHistoryItem(histItem);
+
+			emit jsNewMassSpectrum(mp_massSpecDataSet, "Calculating mass spectrum.",
+					localHistory, m_plottingColor);
+		}
+
+
 	//! Perform a ranged [\p lower -- \p upper] data integration to a drift spectrum.
 	void
 		TicChromPlotWidget::integrateToDt(double lower, double upper)
@@ -525,16 +555,46 @@ namespace msXpSmineXpert
 
 
 	/*/js/
-	 * TicChromPlotWidget.integrateToTicIntensity(lower, upper)
+	 * TicChromPlotWidget.jsIntegrateToDt(lower, upper)
 	 *
-	 * Starts an integration of mass spectra data to a TIC intensity single value
-	 * limiting the data range specified with the numerical arguments.
+	 * Starts an integration of mass spectra data to a drift spectrum limiting the
+	 * data range specified with the numerical arguments.
 	 *
 	 * lower, upper: retention time values limiting the integration. If no values
 	 * are provided, there is no limitation to the integration.
 	 *
-	 * The TIC intensity value is returned
+	 * This function creates a new plot widget to display the obtained results.
 	 */
+	void
+		TicChromPlotWidget::jsIntegrateToDt(double lower, double upper)
+		{
+			// Get the pointer to the x-axis (key axis).
+
+			QCPAxis *xAxis = graph()->keyAxis();
+
+			double rangeStart = lower;
+			if(qIsNaN(rangeStart))
+			{
+				rangeStart = xAxis->range().lower;
+			}
+
+			double rangeEnd = upper;
+			if(qIsNaN(rangeEnd))
+			{
+				rangeEnd = xAxis->range().upper;
+			}
+
+			History localHistory = m_history;
+			HistoryItem *histItem = new HistoryItem;
+			histItem->newIntegrationRange(IntegrationType::RT_TO_DT, rangeStart, rangeEnd);
+
+			// Aggreate the new item to the history.
+			localHistory.appendHistoryItem(histItem);
+
+			emit jsNewDriftSpectrum(mp_massSpecDataSet, "Calculating drift spectrum.",
+					localHistory, m_plottingColor);
+		}
+
 
 	//! Perform a ranged [\p lower -- \p upper] data integration to a single TIC intensity value.
 	void
@@ -630,6 +690,121 @@ namespace msXpSmineXpert
 		}
 
 
+	/*/js/
+	 * TicChromPlotWidget.jsIntegrateToTicIntensity(lower, upper)
+	 *
+	 * Starts an integration of mass spectra data to a TIC intensity single value
+	 * limiting the data range specified with the numerical arguments.
+	 *
+	 * lower, upper: retention time values limiting the integration. If no values
+	 * are provided, there is no limitation to the integration.
+	 *
+	 * The TIC intensity value is returned
+	 */
+	double
+		TicChromPlotWidget::jsIntegrateToTicIntensity(double lower, double upper)
+		{
+			if(m_isMultiGraph)
+				// We cannot perform the action, because this plot widget has not mass
+				// spec data set pointer, it is a graph-only plot widget to display all
+				// the graphs overlaid.
+				return 0;
+
+			// Get the pointer to the x-axis (key axis).
+
+			QCPAxis *xAxis = graph()->keyAxis();
+
+			double rangeStart = lower;
+			if(qIsNaN(rangeStart))
+			{
+				rangeStart = xAxis->range().lower;
+			}
+
+			double rangeEnd = upper;
+			if(qIsNaN(rangeEnd))
+			{
+				rangeEnd = xAxis->range().upper;
+			}
+
+			// Reset the axis range data because we may return prematurely and we want
+			// to craft a stanza with proper values (even if they are qINan()).
+			m_keyRangeStart = qSNaN();
+			m_keyRangeEnd = qSNaN();
+
+			// Also reset the other datum that might hold invalid values.
+			m_lastTicIntensity = qSNaN();
+
+			if(rangeStart == rangeEnd)
+			{
+				return false;
+			}
+
+			// Slot for sorting stuff.
+			double tempVal;
+
+			// Set the values in sorted order for later stanza crafting.
+			if(rangeStart > rangeEnd)
+			{
+				tempVal = rangeStart;
+				rangeStart = rangeEnd;
+				rangeStart = tempVal;
+			}
+
+			History localHistory = m_history;
+			HistoryItem *histItem = new HistoryItem;
+			histItem->newIntegrationRange(IntegrationType::RT_TO_TIC_INT, rangeStart, rangeEnd);
+
+			// At this point store the range data so that the user may use it in
+			// analysis reporting.
+			m_keyRangeStart = rangeStart;
+			m_keyRangeEnd = rangeEnd;
+
+			// Aggreate the new item to the history.
+			localHistory.appendHistoryItem(histItem);
+
+			TicChromWnd *parentWnd = static_cast<TicChromWnd *>(mp_parentWnd);
+
+			// Capture immediately the text that is located in the status bar
+			// because if the computation is long that text will have disappeared
+			// and we won't be able to show it in the TIC int text.
+
+			QString currentMessage = parentWnd->statusBar()->currentMessage();
+
+			QApplication::setOverrideCursor(QCursor(Qt::BusyCursor));
+
+			// Sanity check. It is not possible that this plot widget is not
+			// multi-graph and that at the same time, the mass spec data set pointer
+			// is nullptr.
+
+			if(!m_isMultiGraph && mp_massSpecDataSet == Q_NULLPTR)
+				qFatal("Fatal error at %s@%d -- %s(). "
+						"Programming error."
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__);
+
+			MassDataIntegrator integrator(mp_massSpecDataSet, localHistory);
+
+			integrator.integrateToTicIntensity();
+
+			m_lastTicIntensity = integrator.ticIntensity();
+
+			QApplication::restoreOverrideCursor();
+
+			if(currentMessage.isEmpty())
+				parentWnd->statusBar()->showMessage(QString("range [%1-%2]: TIC I = %3")
+						.arg(m_keyRangeStart, 0, 'f', 3)
+						.arg(m_keyRangeEnd, 0, 'f', 3)
+						.arg(m_lastTicIntensity, 0, 'g', 3));
+			else
+				parentWnd->statusBar()->showMessage(currentMessage +
+						QString(" ; range [%1-%2]: TIC I = %3")
+						.arg(m_keyRangeStart, 0, 'f', 3)
+						.arg(m_keyRangeEnd, 0, 'f', 3)
+						.arg(m_lastTicIntensity, 0, 'g', 3));
+
+			return m_lastTicIntensity;
+		}
+
 
 	//! Perform a ranged [\p lower -- \p upper] data integration to a XIC chromatogram.
 	/*
@@ -664,15 +839,61 @@ namespace msXpSmineXpert
 		}
 
 
-	//! Compute mass spectra statistics on the spectra in the range.
+	/*/js/
+	 * TicChromPlotWidget.jsIntegrateToXic(lower, upper)
+	 *
+	 * Starts an integration of mass spectra data to a XIC chromatogram limiting
+	 * the data range specified with the numerical arguments.
+	 *
+	 * This process is not equivalent to an integration to RT because we do not
+	 * take into account the History of the current plot widget. Indeed, the
+	 * integration is performed without any filtering from the initial mass
+	 * spectrometry data.
+	 *
+	 * lower, upper: retention time values limiting the integration. If no values
+	 * are provided, there is no limitation to the integration.
+	 *
+	 * The TIC intensity value is returned
+	 */
 	void
+		TicChromPlotWidget::jsIntegrateToXic(double lower, double upper)
+		{
+
+			// The history list needs to be empty because we do not want any filtering of
+			// the data apart from the two parameters to this function. However, we
+			// want to keep the mass spectral data integration parameters.
+
+			History localHistory = m_history;
+			localHistory.freeList();
+
+			HistoryItem *histItem = new HistoryItem;
+			histItem->newIntegrationRange(IntegrationType::FILE_TO_XIC, lower, upper);
+
+			// Aggreate the new item to the local history copy we made.
+			localHistory.appendHistoryItem(histItem);
+
+			// The signal is emitted, but the connection to the receiver exists only
+			// if this plot widget is NOT multi-graph. So, even if mp_massSpecDataSet
+			// is nullptr, there is no risk.
+			emit jsNewTicChromatogram(mp_massSpecDataSet, "Calculating extracted ion chromatogram.",
+					localHistory, m_plottingColor);
+		}
+
+
+	/*/js/
+	 * TicChromPlotWidget.statistics()
+	 *
+	 * Compute the mass spectra statistics on the spectra currently in the range.
+	 */
+	//! Compute mass spectra statistics on the spectra in currently the range.
+	QString
 		TicChromPlotWidget::statistics()
 		{
 			if(m_isMultiGraph)
 				// We cannot perform the action, because this plot widget has not mass
 				// spec data set pointer, it is a graph-only plot widget to display all
 				// the graphs overlaid.
-				return ;
+				return QString();
 
 			// Get the pointer to the x-axis (key axis).
 
@@ -707,8 +928,8 @@ namespace msXpSmineXpert
 
 			QApplication::restoreOverrideCursor();
 
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-				<< "Computed statistics\n" << text;
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+			//<< "Computed statistics\n" << text;
 
 			TicChromWnd *parentWnd = static_cast<TicChromWnd *>(mp_parentWnd);
 			MainWindow *mainWindow = static_cast<MainWindow *>(parentWnd->parent());
@@ -716,6 +937,8 @@ namespace msXpSmineXpert
 			mainWindow->logConsoleMessage("\n------------------------------------------------\n");
 			mainWindow->logConsoleMessage(text, m_plottingColor);
 			mainWindow->logConsoleMessage("------------------------------------------------\n");
+
+			return text;
 		}
 
 
@@ -727,7 +950,6 @@ namespace msXpSmineXpert
 	 *
 	 * This function creates a new plot widget to display the <Trace> data.
 	 */
-
 	//! Create a new plot. This function is useful in the scripting environment.
 	void
 		TicChromPlotWidget::newPlot()
@@ -780,7 +1002,6 @@ namespace msXpSmineXpert
 		}
 
 
-
 	//! Key release event handler.
 	/*!
 
@@ -1050,6 +1271,7 @@ namespace msXpSmineXpert
 		}
 
 
+	//! Mouse event handler.
 	void
 		TicChromPlotWidget::mousePressHandler(QMouseEvent *event)
 		{
@@ -1057,6 +1279,13 @@ namespace msXpSmineXpert
 		}
 
 
+	/*/js/
+	 * TicChromPlotWidget.jsSetMzIntegrationParams(mzIntegrationParams)
+	 *
+	 * Set the m/z integration parameters object passed as parameter to this plot
+	 * widget so that they are taken into account for the next integrations to a
+	 * mass spectrum.
+	 */
 	void
 		TicChromPlotWidget::jsSetMzIntegrationParams()
 		{
@@ -1108,6 +1337,15 @@ namespace msXpSmineXpert
 		}
 
 
+	/*/js/
+	 * TicChromPlotWidget.jsMzIntegrationParams()
+	 *
+	 * Return the MzIntegrationParams object currently set for this color map
+	 * plot widget.
+	 *
+	 * These parameters are taken into account for the integrations to a mass
+	 * spectrum.
+	 */
 	QScriptValue
 		TicChromPlotWidget::jsMzIntegrationParams() const
 		{
@@ -1127,7 +1365,5 @@ namespace msXpSmineXpert
 			return IntegrationType::RT_TO_XXX;
 		}
 
-
-
 }
 // namespace msXpSmineXpert
