@@ -482,11 +482,15 @@ namespace msXpSmineXpert
 			// plot widgets that were created as the result of an integration
 			// computation of the plot widget currently being destroyed.
 
-			connect(widget, &AbstractPlotWidget::destroyPlotWidget, mainWindow,
+			connect(widget,
+					&AbstractPlotWidget::destroyPlotWidget,
+					mainWindow,
 					&MainWindow::destroyAlsoAllTargetPlotWidgets);
 
-			connect(widget, &AbstractPlotWidget::toggleMultiGraphSignal,
-					mainWindow, &MainWindow::toggleMultiGraph);
+			connect(widget,
+					&AbstractPlotWidget::toggleMultiGraphSignal,
+					mainWindow,
+					&MainWindow::toggleMultiGraph);
 
 			// Ensure that there is a connexion between this new widget and the
 			// MassSpecWnd instance that will receive the signal requiring to make a
@@ -494,18 +498,35 @@ namespace msXpSmineXpert
 			// chromatogram plot.
 
 			connect(static_cast<TicChromPlotWidget *>(widget),
-					&TicChromPlotWidget::newMassSpectrum, mainWindow->mp_massSpecWnd,
+					&TicChromPlotWidget::newMassSpectrum,
+					mainWindow->mp_massSpecWnd,
 					&MassSpecWnd::newMassSpectrum);
 
 			connect(static_cast<TicChromPlotWidget *>(widget),
-					&TicChromPlotWidget::newDriftSpectrum, mainWindow->mp_driftSpecWnd,
+					&TicChromPlotWidget::jsNewMassSpectrum,
+					mainWindow->mp_massSpecWnd,
+					&MassSpecWnd::jsNewMassSpectrum);
+
+			connect(static_cast<TicChromPlotWidget *>(widget),
+					&TicChromPlotWidget::newDriftSpectrum,
+					mainWindow->mp_driftSpecWnd,
 					&DriftSpecWnd::newDriftSpectrum);
 
+			connect(static_cast<TicChromPlotWidget *>(widget),
+					&TicChromPlotWidget::jsNewDriftSpectrum,
+					mainWindow->mp_driftSpecWnd,
+					&DriftSpecWnd::jsNewDriftSpectrum);
+
 			connect(static_cast<TicChromPlotWidget *>(widget),
 					&TicChromPlotWidget::newTicChromatogram,
 					this,
 					&TicChromWnd::newTicChromatogram);
 
+			connect(static_cast<TicChromPlotWidget *>(widget),
+					&TicChromPlotWidget::jsNewTicChromatogram,
+					this,
+					&TicChromWnd::jsNewTicChromatogram);
+
 			connect(static_cast<TicChromPlotWidget *>(widget),
 					&TicChromPlotWidget::ticIntensitySignal,
 					this,
@@ -534,6 +555,198 @@ namespace msXpSmineXpert
 		}
 
 
+	void
+		TicChromWnd::jsInitialTic(const MassSpecDataSet *p_massSpecDataSet, QColor color)
+		{
+
+			if(p_massSpecDataSet == Q_NULLPTR)
+				qFatal("Fatal error at %s@%d -- %s(). "
+						"Pointer cannot be nullptr."
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__);
+
+			// The mass data integration processes are handled by the
+			// MassDataIntegrator object.
+
+			MassDataIntegrator integrator(p_massSpecDataSet);
+
+			integrator.initialTic();
+
+			History localHistory = integrator.history();
+
+			// At this point what we should do is transfer the data to the plotting
+			// widget creation routine. Note that we are creating the very first plot
+			// widget with data just loaded from a mass spec file. That plot widget
+			// will be later connected to the destruction of the mass spec data set
+			// when the plot widget itself is deleted (see true param in newRelation
+			// call below).
+
+			AbstractPlotWidget *widget = addPlotWidget(
+					integrator.keyVector(), integrator.valVector(),
+					p_massSpecDataSet->fileName(), color, p_massSpecDataSet);
+
+			// For this specific TIC chrom widget, that is created for storing the
+			// initial mass spec data set as read from file, we set it as parent of
+			// the mass spec data set, so that when the widget is destroyed, the mass
+			// spec data set also. Ugly, but we need to cast to non-const.
+			const_cast<MassSpecDataSet *>(p_massSpecDataSet)->setParent(widget);
+
+			// Before updating the history of the widget, update the history with the
+			// two critical data bits that will be conditioning the way future
+			// integrations are performed: the smallestStep value that goes along the
+			// msXpS::MassToleranceType::MASS_TOLERANCE_MZ.
+
+			MassSpecDataStats stats = p_massSpecDataSet->statistics();
+
+			MzIntegrationParams paramsToApply;
+
+			if(stats.m_spectrumCount <= 1)
+			{
+				// There is no interest to perform any binning when there is at most one
+				// spectrum.
+
+				MzIntegrationParams params(BinningType::BINNING_TYPE_NONE,
+						0.005,
+						msXpS::MassToleranceType::MASS_TOLERANCE_MZ,
+						false /* apply mz shift */,
+						false /* remove 0-val data points */);
+
+				paramsToApply = params;
+			}
+			else
+			{
+				// Use the statistics to setup the initial mz integration params to the
+				// history of the plot widget. Note that we set the binning type to
+				// arbitrary with the bin size set to twice the smallest m/z step observed
+				// throughout all the data points of all the spectra of the file.
+
+				MzIntegrationParams params(BinningType::BINNING_TYPE_ARBITRARY,
+
+						// This was the first version, but that value is not robuts: many
+						// times it happens to be 0, so the 0.001 default value would be set.
+						// That m_smallestStep value is too low for most occasions.
+						// m_smallestStep,
+
+						// This was the second version:
+						// The m_smallestStepAvg is the most robust.
+						// stats.m_smallestStepAvg,
+
+						// This is currently the last version
+						// The m_smallestMedian is the most robust.
+						stats.m_smallestStepMedian,
+						msXpS::MassToleranceType::MASS_TOLERANCE_MZ,
+						false /* apply mz shift */,
+
+						// Note that when binning is set, then removing the 0-val data points
+						// is recommended.
+						true /* remove 0-val data points */);
+
+				paramsToApply = params;
+			}
+
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+			//<< "stats.m_smallestStepAvg =" << stats.m_smallestStepAvg;
+
+			localHistory.setMzIntegrationParams(paramsToApply);
+
+			// At this point, make sure that the widget has the new version of the
+			// history.
+
+			widget->rhistory().copyHistory(localHistory, true /*remove duplicates*/);
+
+			// Log the history to the console.
+			MainWindow *mainWindow = static_cast<MainWindow *>(parent());
+			mainWindow->logConsoleMessage(widget->history().innermostRangesAsText());
+
+			//qDebug() << __FILE__ << __LINE__
+			//<< "After initialTic was computed, history:"
+			//<< widget->history().asText();
+
+			mainWindow->logConsoleMessage(stats.asText(), color);
+
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+			//<< "Statistics: " << p_massSpecDataSet->statisticsAsText();
+
+			// The plot widget reacts to the Qt::Key_Delete key by calling a function
+			// that emits a set of signals, of which the destroyPlotWidget signal
+			// actually indirectly triggers the destruction of the plot widget. This
+			// signal is now connected to the main window where a function will call
+			// for the destruction of all the target plot widgets, that is all the
+			// plot widgets that were created as the result of an integration
+			// computation of the plot widget currently being destroyed.
+
+			connect(widget, &AbstractPlotWidget::destroyPlotWidget, mainWindow,
+					&MainWindow::destroyAlsoAllTargetPlotWidgets);
+
+			connect(widget, &AbstractPlotWidget::toggleMultiGraphSignal,
+					mainWindow, &MainWindow::toggleMultiGraph);
+
+			// Ensure that there is a connexion between this new widget and the
+			// MassSpecWnd instance that will receive the signal requiring to make a
+			// mass spectrum on the basis of an integration selection in the TIC
+			// chromatogram plot.
+
+			connect(static_cast<TicChromPlotWidget *>(widget),
+					&TicChromPlotWidget::newMassSpectrum,
+					mainWindow->mp_massSpecWnd,
+					&MassSpecWnd::newMassSpectrum);
+
+			connect(static_cast<TicChromPlotWidget *>(widget),
+					&TicChromPlotWidget::jsNewMassSpectrum,
+					mainWindow->mp_massSpecWnd,
+					&MassSpecWnd::jsNewMassSpectrum);
+
+			connect(static_cast<TicChromPlotWidget *>(widget),
+					&TicChromPlotWidget::newDriftSpectrum,
+					mainWindow->mp_driftSpecWnd,
+					&DriftSpecWnd::newDriftSpectrum);
+
+			connect(static_cast<TicChromPlotWidget *>(widget),
+					&TicChromPlotWidget::jsNewDriftSpectrum,
+					mainWindow->mp_driftSpecWnd,
+					&DriftSpecWnd::jsNewDriftSpectrum);
+
+			connect(static_cast<TicChromPlotWidget *>(widget),
+					&TicChromPlotWidget::newTicChromatogram,
+					this,
+					&TicChromWnd::newTicChromatogram);
+
+			connect(static_cast<TicChromPlotWidget *>(widget),
+					&TicChromPlotWidget::jsNewTicChromatogram,
+					this,
+					&TicChromWnd::jsNewTicChromatogram);
+
+			connect(static_cast<TicChromPlotWidget *>(widget),
+					&TicChromPlotWidget::ticIntensitySignal,
+					this,
+					&TicChromWnd::ticIntensity);
+
+
+			// Ensure that there is a connection between this plot widget and this
+			// containing window, such that if there is a requirement to replot, the
+			// widget gets the signal.
+			connect(this, &TicChromWnd::replotWithAxisRange, widget,
+					&TicChromPlotWidget::replotWithAxisRange);
+
+			// Make sure we get the signal requiring to redraw the background of the
+			// widget, depending on it being focused or not.
+			connect(this, &AbstractMultiPlotWnd::redrawPlotBackground, widget,
+					&AbstractPlotWidget::redrawPlotBackground);
+
+			// Set this newly created widget to be the last-focused widget.
+			widget->setFocus();
+			mp_lastFocusedPlotWidget = widget;
+			updateMzIntegrationParams(widget->history().mzIntegrationParams());
+
+
+			// Now call the main window of the program to finalize the widget
+			// establishment.
+			mainWindow->initialTicDone(widget, p_massSpecDataSet, color);
+		}
+
+
+
+
 	//! Integrate data to TIC chromatogram.
 	/*!
 
@@ -682,18 +895,40 @@ namespace msXpSmineXpert
 			connect(this, &AbstractMultiPlotWnd::redrawPlotBackground, widget,
 					&AbstractPlotWidget::redrawPlotBackground);
 
-			connect(widget, &TicChromPlotWidget::newMassSpectrum,
-					mainWindow->mp_massSpecWnd, &MassSpecWnd::newMassSpectrum);
+			connect(widget,
+					&TicChromPlotWidget::newMassSpectrum,
+					mainWindow->mp_massSpecWnd,
+					&MassSpecWnd::newMassSpectrum);
 
-			connect(widget, &TicChromPlotWidget::newDriftSpectrum,
-					mainWindow->mp_driftSpecWnd, &DriftSpecWnd::newDriftSpectrum);
+			connect(widget,
+					&TicChromPlotWidget::jsNewMassSpectrum,
+					mainWindow->mp_massSpecWnd,
+					&MassSpecWnd::jsNewMassSpectrum);
 
-			// FIXME For the XIC extraction ?
-			connect(widget, &TicChromPlotWidget::newTicChromatogram,
-					this, &TicChromWnd::newTicChromatogram);
+			connect(widget,
+					&TicChromPlotWidget::newDriftSpectrum,
+					mainWindow->mp_driftSpecWnd,
+					&DriftSpecWnd::newDriftSpectrum);
 
-			connect(widget, &TicChromPlotWidget::ticIntensitySignal,
-					mainWindow->mp_ticChromWnd, &TicChromWnd::ticIntensity);
+			connect(widget,
+					&TicChromPlotWidget::jsNewDriftSpectrum,
+					mainWindow->mp_driftSpecWnd,
+					&DriftSpecWnd::jsNewDriftSpectrum);
+
+			connect(widget,
+					&TicChromPlotWidget::newTicChromatogram,
+					this,
+					&TicChromWnd::newTicChromatogram);
+
+			connect(widget,
+					&TicChromPlotWidget::jsNewTicChromatogram,
+					this,
+					&TicChromWnd::jsNewTicChromatogram);
+
+			connect(widget,
+					&TicChromPlotWidget::ticIntensitySignal,
+					mainWindow->mp_ticChromWnd,
+					&TicChromWnd::ticIntensity);
 
 			mainWindow->m_dataPlotWidgetRelationer.newRelation(
 					integrator->massSpecDataSet(), senderPlotWidget, widget,
@@ -704,6 +939,156 @@ namespace msXpSmineXpert
 		}
 
 
+	//! Integrate data to TIC chromatogram.
+	/*!
+
+		\param massSpecDataSet pointer to the MassSpecDataSet where the mass data
+		are stored.
+
+		\param integrationType IntegrationType of the integration to be performed.
+
+		\param history History to account for the integration.
+
+		\param color to use to plot the graph of the new mass spectrum.
+
+*/
+	void
+		TicChromWnd::jsNewTicChromatogram(const MassSpecDataSet *massSpecDataSet,
+				const QString &msg, History history, QColor color)
+		{
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+			//<< "Entering";
+
+			if(massSpecDataSet == Q_NULLPTR)
+				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
+
+			// Make sure the cancel button is visible.
+			mp_statusBarCancelPushButton->setVisible(true);
+
+			MassDataIntegrator integrator(massSpecDataSet, history);
+
+			connect(&integrator,
+					&MassDataIntegrator::updateFeedbackSignal,
+					this,
+					&AbstractMultiPlotWnd::updateFeedback);
+
+			connect(this,
+					&AbstractMultiPlotWnd::cancelOperationSignal,
+					&integrator,
+					&MassDataIntegrator::cancelOperation);
+
+			integrator.integrate();
+
+			//qDebug() << "At this point the integration is finished. Desetup the feedback.";
+
+			//De-setup the feedback.
+			QTimer::singleShot(2000, this, [=]()
+					{
+					updateFeedback("", -1, false /* setVisible */, LogType::LOG_TO_STATUS_BAR);
+					}
+					);
+
+			// Make sure the cancel button is hidden.
+			mp_statusBarCancelPushButton->setVisible(false);
+
+			// Create a text item to indicate the last history item.
+
+			QString historyItemText = history.newestHistoryItem()->asText(true /* brief */);
+
+			QString plotText = QString("%1\n%2 - %3 ")
+				.arg(massSpecDataSet->fileName())
+				.arg(m_desc)
+				.arg(historyItemText);
+
+			// Allocate the new plot widget in which the data are to be plot.
+
+			TicChromPlotWidget *widget = static_cast<TicChromPlotWidget *>(
+					addPlotWidget(integrator.keyVector(), integrator.valVector(),
+						plotText, color, massSpecDataSet));
+
+			// The history that we get as a parameter needs to be appended to the new
+			// widget's history so that we have a full account of the history.
+
+			widget->rhistory().copyHistory(history, true /*remove duplicates*/);
+
+			MainWindow *mainWindow = static_cast<MainWindow *>(parent());
+			mainWindow->logConsoleMessage(widget->history().asText(
+						"Plot widget history: \n", "End plot widget history:\n"));
+			// And now only the innermost ranges of the whole history.
+			mainWindow->logConsoleMessage(widget->history().innermostRangesAsText());
+
+			// The plot widget reacts to the Qt::Key_Delete key by calling a function
+			// that emits a set of signals, of which the destroyPlotWidget signal
+			// actually indirectly triggers the destruction of the plot widget. This
+			// signal is now connected to the main window where a function will call for
+			// the destruction of all the target plot widgets, that is all the plot
+			// widgets that were created as the result of an integration computation of
+			// the plot widget currently being destroyed.
+
+			connect(widget, &AbstractPlotWidget::destroyPlotWidget, mainWindow,
+					&MainWindow::destroyAlsoAllTargetPlotWidgets);
+
+			connect(widget, &AbstractPlotWidget::toggleMultiGraphSignal,
+					mainWindow, &MainWindow::toggleMultiGraph);
+
+			// Ensure that there is a connection between this plot widget and this
+			// containing window, such that if there is a requirement to replot, the
+			// widget gets the signal.
+
+			connect(this, &AbstractMultiPlotWnd::replotWithAxisRange, widget,
+					&AbstractPlotWidget::replotWithAxisRange);
+
+			// Make sure we get the signal requiring to redraw the background of the
+			// widget, depending on it being focused or not.
+
+			connect(this, &AbstractMultiPlotWnd::redrawPlotBackground, widget,
+					&AbstractPlotWidget::redrawPlotBackground);
+
+			connect(widget,
+					&TicChromPlotWidget::newMassSpectrum,
+					mainWindow->mp_massSpecWnd,
+					&MassSpecWnd::newMassSpectrum);
+
+			connect(static_cast<TicChromPlotWidget *>(widget),
+					&TicChromPlotWidget::jsNewMassSpectrum,
+					mainWindow->mp_massSpecWnd,
+					&MassSpecWnd::jsNewMassSpectrum);
+
+			connect(widget,
+					&TicChromPlotWidget::newDriftSpectrum,
+					mainWindow->mp_driftSpecWnd,
+					&DriftSpecWnd::newDriftSpectrum);
+
+			connect(widget,
+					&TicChromPlotWidget::jsNewDriftSpectrum,
+					mainWindow->mp_driftSpecWnd,
+					&DriftSpecWnd::jsNewDriftSpectrum);
+
+			connect(widget,
+					&TicChromPlotWidget::newTicChromatogram,
+					this,
+					&TicChromWnd::newTicChromatogram);
+
+			connect(widget,
+					&TicChromPlotWidget::jsNewTicChromatogram,
+					this,
+					&TicChromWnd::jsNewTicChromatogram);
+
+			AbstractPlotWidget *senderPlotWidget =
+				dynamic_cast<AbstractPlotWidget *>(QObject::sender());
+
+			if(senderPlotWidget == Q_NULLPTR)
+				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
+
+			mainWindow->m_dataPlotWidgetRelationer.newRelation(
+					massSpecDataSet, senderPlotWidget, widget,
+					Q_NULLPTR /* open spectra dialog list widget item */);
+
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+			//<< "Exiting";
+		}
+
+
 	void
 		TicChromWnd::ticIntensity(const MassSpecDataSet *massSpecDataSet,
 				const QString &msg, History history)
