@@ -260,7 +260,7 @@ namespace msXpSmineXpert
 			{
 
 				//qDebug() << __FILE__ << __LINE__
-					//<< "Current mz,i textual pair:" << mzIstringList.at(iter);
+				//<< "Current mz,i textual pair:" << mzIstringList.at(iter);
 
 				match = realDataRegExp.match(mzIstringList.at(iter));
 
@@ -293,14 +293,14 @@ namespace msXpSmineXpert
 					// spectrum that we allocated at the beginning of this function.
 
 					//qDebug() << __FILE__ << __LINE__
-						//<< "Appending MassPeak:" << mz << "-" << i;
+					//<< "Appending MassPeak:" << mz << "-" << i;
 
 					massSpectrum->append(new msXpSlibmass::DataPoint(mz, i));
 				}
 			}
 
 			//qDebug() << __FILE__ << __LINE__
-				//<< "Returning mass spectrum of " << massSpectrum->size() << "points";
+			//<< "Returning mass spectrum of " << massSpectrum->size() << "points";
 
 			return massSpectrum;
 		}
@@ -366,8 +366,8 @@ namespace msXpSmineXpert
 					return -1;
 				}
 				//qDebug() << __FILE__ << __LINE__
-					//<< "rt:"
-					//<< match.captured(1);
+				//<< "rt:"
+				//<< match.captured(1);
 
 				numberPoints = match.captured(8).toInt(&ok);
 				if(!ok)
@@ -378,14 +378,14 @@ namespace msXpSmineXpert
 					return -1;
 				}
 				//qDebug() << __FILE__ << __LINE__
-					//<< "number of points in spectrum:"
-					//<< match.captured(8);
+				//<< "number of points in spectrum:"
+				//<< match.captured(8);
 
 				spectralData = match.captured(9);
 
 				//qDebug() << __FILE__ << __LINE__
-					//<< "matched the spectral data with string:"
-					//<< match.captured(9);
+				//<< "matched the spectral data with string:"
+				//<< match.captured(9);
 
 				msXpSlibmass::MassSpectrum *newSpectrum = parseSpectrum(spectralData);
 
@@ -457,8 +457,8 @@ namespace msXpSmineXpert
 
 				QString msg = QString("Parsed spectrum number %1\n").arg(spectraRead);
 
-				emit dataLoadMessageSignal(msg, LOG_TO_BOTH);
-				emit dataLoadProgressSignal(spectraRead);
+				emit updateFeedbackSignal(msg, spectraRead, true /* setVisible */,
+						LogType::LOG_TO_BOTH);
 			}
 			// End of
 			// while(!file.atEnd())
@@ -596,7 +596,7 @@ namespace msXpSmineXpert
 
 			QString msgSkeleton = "Computing streamed m/z integration";
 
-			emit setupFeedbackSignal(msgSkeleton, 0, 0, -1, LogType::LOG_TO_BOTH);
+			emit updateFeedbackSignal(msgSkeleton, 0, true /*setVisible */, LogType::LOG_TO_BOTH);
 
 			QFile file(m_fileName);
 
@@ -807,7 +807,7 @@ namespace msXpSmineXpert
 					QString msg =
 						QString(" -- spectrum number %1\n").arg(spectraRead);
 
-					emit updateFeedbackSignal(msgSkeleton + msg, -1, LogType::LOG_TO_STATUS_BAR);
+					emit updateFeedbackSignal(msgSkeleton + msg, -1, true /* setVisible */, LogType::LOG_TO_STATUS_BAR);
 
 					//qDebug() << __FILE__ << __LINE__ << msg;
 				}
