@@ -104,18 +104,14 @@ namespace msXpSmineXpert
 
 		private:
 
+		pwiz::msdata::MSData m_msDataResult;
+
+
 		//! Pointer to a pwiz-based data reader.
 		pwiz::msdata::ReaderPtr mp_pwizReader = Q_NULLPTR;
 
-		//! Handler of SQLite3-based mass data.
-		/*!
-
-			When this loader is used to convert mass spectrometry data from mzML to
-			SQLite3-based db format, then this member is required to craft SQL-based
-			statements to feed data into the database file.
-
-*/
-		MassSpecSqlite3Handler m_sqlite3Handler;
+		//! Pointer to the spectrum list
+		pwiz::msdata::SpectrumListPtr mp_spectrumListPtr = Q_NULLPTR;
 
 		//! Holder for details of the mass spectrometry data file.
 		MassSpecFileMetaData m_msFileMetaData;
@@ -458,22 +454,25 @@ namespace msXpSmineXpert
 
 		QString formatDescription() const override;
 
+		void updateLoadProgression(int count);
+
 		void resetSpectralData();
 		void resetMobilityData();
 
 		void seedMobilityData();
 		bool containsMobilityData();
 
-		void updateLoadProgression(int count);
+		bool seedDataLoading();
+
+		int nextSpectrum(pwiz::msdata::SpectrumPtr *p_spectrumPtr);
+
+		msXpSlibmass::MassSpectrum *createNewSpectrum(pwiz::msdata::SpectrumPtr spectrumPtr);
 
 		int loadSpectrumToMassSpecDataSet();
-		int loadSpectrumToVectors();
-		int loadSpectrumToXyFilesInSequence();
 
 		int integrateToRt();
 		int integrateToMz();
 		int integrateToDt();
-		int loadData();
 
 		public:
 
@@ -487,12 +486,12 @@ namespace msXpSmineXpert
 		static int canLoadData(QString fileName, MassSpecDataFileLoaderPwiz *pwiz = Q_NULLPTR);
 		int readSpectrumCount() override;
 
-		int loadData(MassSpecDataSet *massSpecDataSet);
-		int loadData(const QString &dbFileName);
-		int loadData(const QString &xyFileName, int startIndex, int endIndex);
-		int loadData(const History &history, IntegrationType integrationType,
-				QVector<double> *keyVector, QVector<double> *valVector,
-				double *intensity);
+		int loadDataToMassSpecDataSet(MassSpecDataSet *massSpecDataSet);
+
+		int loadDataToXyFiles(const QString &xyFileName, int startIndex, int endIndex);
+
+		// Loading data to database is a conversion to the SQLite3 db format
+		int loadDataToDatabase(const QString &dbFileName);
 
 		int streamedIntegration(const History & history,
 				IntegrationType integrationType,
