@@ -294,11 +294,10 @@ namespace msXpSmineXpert
 
 			if(sqlQuery->isValid())
 			{
-				qDebug()
-					<< __FILE__ << __LINE__
-					<< "A metadata record is already found in the database. Exiting.\n";
-
-				exit(1);
+				qFatal("Fatal error at %s@%d -- %s(). "
+						"A metadata record is already found in the database."
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__);
 			}
 
 			// No record is found in the metadata table. Make an INSERT.
@@ -314,14 +313,11 @@ namespace msXpSmineXpert
 
 			if(!ok)
 			{
-				QSqlError sqlError = sqlQuery->lastError();
-				QString error = sqlError.text();
-
-				qDebug() << __FILE__ << __LINE__
-					<< "Failed to store the metadata in the database.\n"
-					<< "SQL error:" << error << ". Exiting.\n";
-
-				exit(1);
+				qFatal("Fatal error at %s@%d -- %s(). Error: %s."
+						"Failed to store the metadata in the database.\n"
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__,
+						sqlQuery->lastError().text().toLatin1().data());
 			}
 			else
 			{
@@ -830,10 +826,10 @@ namespace msXpSmineXpert
 
 			if(!createMetaDataTableSpecifs())
 			{
-				qDebug()
-					<< __FILE__ << __LINE__
-					<< "Failed to create the metaData table specifications. Exiting.\n";
-				exit(1);
+				qFatal("Fatal error at %s@%d -- %s(). "
+						"Failed to create the metaData table specifications.."
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__);
 			}
 
 			// Ask for the sql string that will allow us to create the
@@ -943,14 +939,26 @@ namespace msXpSmineXpert
 		MassSpecSqlite3Handler::initializeDbForRead(QSqlDatabase &database, bool readMetaData)
 		{
 			if(!database.isOpen() || !database.isValid())
+			{
 				if(!database.open())
+				{
+					qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+						<< "The database was not open and could not be opened";
+
 					return false;
+				}
+				//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+				//<< "The database was not open and could be opened.";
+			}
 
 			// Now initialize the m_msFileMetaData with data from the database (if so
 			// requested)
 			if(readMetaData)
 				m_msFileMetaData = getMassSpecFileMetaDataFromDb(database);
 
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+			//<< "The list of tables:" << database.tables();
+
 			return true;
 		}
 
@@ -1038,11 +1046,11 @@ namespace msXpSmineXpert
 
 			if(!ok)
 			{
-				qDebug() << __FILE__ << __LINE__
-					<< "Failed to get proper data from the database.\n"
-					<< sqlQuery.lastError() << "Exiting.\n";
-
-				exit(1);
+				qFatal("Fatal error at %s@%d -- %s(). Error: %s."
+						"Failed to get proper data from the database.\n"
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__,
+						sqlQuery.lastError().text().toLatin1().data());
 			}
 
 			sqlQuery.first();
@@ -1275,7 +1283,7 @@ namespace msXpSmineXpert
 			// for a mobility drift time experiment.
 
 			if(!initializeDbForRead(database, false /* readMetaData */))
-				return -1;
+				return false;
 
 			QSqlQuery sqlQuery(database);
 			bool ok = false;
@@ -1295,16 +1303,25 @@ namespace msXpSmineXpert
 						msg.toLatin1().data());
 			}
 
-			if(!sqlQuery.first())
-			{
-				QString msg =
-					QString("Failed to get proper data from the database. Error: %1. Exiting.\n")
-					.arg(sqlQuery.lastError().text());
+			if(!sqlQuery.isActive())
+				qFatal("Fatal error at %s@%d -- %s(). "
+						"The query failed: it is not active."
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__);
 
-				qFatal("Fatal error at %s@%d -- %s: %s",
+
+			if(!sqlQuery.isSelect())
+				qFatal("Fatal error at %s@%d -- %s(). "
+						"The query failed: it is not a SELECT query."
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__);
+
+			if(!sqlQuery.first())
+				qFatal("Fatal error at %s@%d -- %s(). "
+						"Failed to get proper data from the database. Error:%s."
+						"Program aborted.",
 						__FILE__, __LINE__, __FUNCTION__,
-						msg.toLatin1().data());
-			}
+						sqlQuery.lastError().text().toLatin1().data());
 
 			int count = sqlQuery.value(0).toInt(&ok);
 
@@ -1519,14 +1536,17 @@ namespace msXpSmineXpert
 		{
 
 			if(!initializeDbForRead(srcDatabase))
-				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
+				qFatal("Fatal error at %s@%d -- %s(). "
+						"Failed to initialize the database for reading."
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__);
 
 			QSqlQuery *srcSqlQuery = new QSqlQuery(srcDatabase);
 
 			if(srcSqlQuery == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
-			QString srcDbQueryString = "SELECT driftTime, driftBin FROM driftData ";
+			QString srcDbQueryString = "SELECT driftTime, driftBin FROM driftData";
 
 			bool ok = srcSqlQuery->exec(srcDbQueryString);
 
@@ -1633,9 +1653,9 @@ namespace msXpSmineXpert
 			}
 			else
 			{
-				qDebug() << __FILE__ << __LINE__ << "Opening data export destination "
-					"database: Success. Now creating "
-					"the tables.";
+				//qDebug() << __FILE__ << __LINE__ << "Opening data export destination "
+				//"database: Success. Now creating "
+				//"the tables.";
 			}
 
 			if(!createDbTables(dstDatabase))
@@ -1650,9 +1670,9 @@ namespace msXpSmineXpert
 			}
 			else
 			{
-				qDebug() << __FILE__ << __LINE__
-					<< "Creating tables for destination database: Success. "
-					<< "The destination database now has the proper structure.\n";
+				//qDebug() << __FILE__ << __LINE__
+				//<< "Creating tables for destination database: Success. "
+				//<< "The destination database now has the proper structure.\n";
 			}
 
 			// At this point, we need to make sure we have all the rt/dt
@@ -1666,8 +1686,8 @@ namespace msXpSmineXpert
 			double rtEnd = -1;
 			rtIntegration = history.innermostRtRange(&rtStart, &rtEnd);
 
-			qDebug() << __FILE__ << __LINE__
-				<< "RT integration:" << rtIntegration << "[" << rtStart << "," << rtEnd << "]";
+			//qDebug() << __FILE__ << __LINE__
+			//<< "RT integration:" << rtIntegration << "[" << rtStart << "," << rtEnd << "]";
 
 			// MZ integration.
 			// ===============
@@ -1684,23 +1704,24 @@ namespace msXpSmineXpert
 			double dtEnd = -1;
 			dtIntegration = history.innermostDtRange(&dtStart, &dtEnd);
 
-			qDebug() << __FILE__ << __LINE__
-				<< "DT integration:" << dtIntegration << "[" << dtStart << "," << dtEnd << "]";
+			//qDebug() << __FILE__ << __LINE__
+			//<< "DT integration:" << dtIntegration << "[" << dtStart << "," << dtEnd << "]";
 
 			// We need to craft a SqlQuery string that is specific of the experimental
 			// situation: are we dealing with drift data or not.
 
 			bool wasDriftExperiment = isDriftExperiment(srcDatabase);
 
-			qDebug() << __FILE__ << __LINE__
-				<< "wasDriftExperiment: " << wasDriftExperiment;
+			//qDebug() << __FILE__ << __LINE__
+			//<< "wasDriftExperiment: " << wasDriftExperiment;
 
 			if(wasDriftExperiment)
 			{
 				if(!exportData_driftData(srcDatabase, dstDatabase))
-					qFatal("Fatal error at %s@%d. Failed to export the driftData table. "
+					qFatal("Fatal error at %s@%d -- %s(). "
+							"Failed to export the driftData table."
 							"Program aborted.",
-							__FILE__, __LINE__);
+							__FILE__, __LINE__, __FUNCTION__);
 			}
 
 			QString srcDbQueryString;
@@ -1779,9 +1800,9 @@ namespace msXpSmineXpert
 
 				if(dtIntegration)
 				{
-					qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-						<< "dtIntegration is true with dtStart:" << dtStart
-						<< "dtEnd:" << dtEnd;
+					//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+					//<< "dtIntegration is true with dtStart:" << dtStart
+					//<< "dtEnd:" << dtEnd;
 
 					if(oneAlready)
 					{
@@ -1802,8 +1823,8 @@ namespace msXpSmineXpert
 				}
 			}
 
-			qDebug() << __FILE__ << __LINE__
-				<< "whereStatements:" << whereStatements;
+			//qDebug() << __FILE__ << __LINE__
+			//<< "whereStatements:" << whereStatements;
 
 			// And now, make sure the member database, the source database is fine.
 
@@ -1822,8 +1843,8 @@ namespace msXpSmineXpert
 				condFields + fromStatement + joinStatements +
 				whereStatements;
 
-			qDebug() << __FILE__ << __LINE__
-				<< "For record counting, the query string is: " << srcDbQueryString;
+			//qDebug() << __FILE__ << __LINE__
+			//<< "For record counting, the query string is: " << srcDbQueryString;
 
 			ok = srcSqlQuery->exec(srcDbQueryString);
 
@@ -1866,8 +1887,8 @@ namespace msXpSmineXpert
 			int recordCount =
 				srcSqlQuery->value(srcSqlQuery->record().indexOf("COUNT(*)")).toInt();
 
-			qDebug() << __FILE__ << __LINE__
-				<< "The recordCount:" << recordCount;
+			//qDebug() << __FILE__ << __LINE__
+			//<< "The recordCount:" << recordCount;
 
 			// Now reset the query
 			srcSqlQuery->finish();
@@ -1877,8 +1898,8 @@ namespace msXpSmineXpert
 			srcDbQueryString = openingStatement + uncondFields + condFields +
 				fromStatement + joinStatements + whereStatements;
 
-			qDebug() << __FILE__ << __LINE__
-				<< "For data export, now, the query string is: " << srcDbQueryString;
+			//qDebug() << __FILE__ << __LINE__
+			//<< "For data export, now, the query string is: " << srcDbQueryString;
 
 			ok = srcSqlQuery->exec(srcDbQueryString);
 
@@ -1944,9 +1965,9 @@ namespace msXpSmineXpert
 			{
 				++iteration;
 
-			emit updateFeedbackSignal("Exporting data", iteration, true /* setVisible */,
-					LogType::LOG_TO_BOTH,
-					m_progressFeedbackStartValue, m_progressFeedbackEndValue);
+				emit updateFeedbackSignal("Exporting data", iteration, true /* setVisible */,
+						LogType::LOG_TO_BOTH,
+						m_progressFeedbackStartValue, m_progressFeedbackEndValue);
 
 				// qDebug() << __FILE__ << __LINE__
 				// << "updateFeedbackSignal: Exporting data..." << iteration;
@@ -2102,7 +2123,7 @@ namespace msXpSmineXpert
 			QSqlDatabase srcDatabase =
 				QSqlDatabase::addDatabase("QSQLITE", connectionName);
 
-			srcDatabase.setDatabaseName(dstFileName);
+			srcDatabase.setDatabaseName(srcFileName);
 
 			bool ok = false;
 
@@ -2120,8 +2141,8 @@ namespace msXpSmineXpert
 			}
 			else
 			{
-				qDebug() << __FILE__ << __LINE__ << "Opening data export source "
-					"database: Success. Now creating the tables.";
+				//qDebug() << __FILE__ << __LINE__ << "Opening data export source "
+				//"database: Success. Now creating the tables.";
 			}
 
 			return exportData(srcDatabase, dstFileName, history);
